@@ -1,3 +1,5 @@
+from typing import List
+
 from xlsx_lib.domain.json_serializable.custom_json_serializable import JSONSerializable
 
 from xlsx_lib.domain.electronic.element_component import ElementComponent
@@ -9,4 +11,4 @@ class ElectronicElement(JSONSerializable):
             name: str,
     ):
         self.name: str = name
-        self.components: list[ElementComponent] = list()
+        self.components: List[ElementComponent] = list()
