@@ -1,4 +1,4 @@
-from typing import Union
+from typing import Union, List
 
 from xlsx_lib.domain.json_serializable.custom_json_serializable import JSONSerializable
 
@@ -9,9 +9,9 @@ class FrameElement(JSONSerializable):
             self,
             name: str,
             value: str,
-            observations: Union[str, list[str]],
+            observations: Union[str, List[str]],
     ):
         self.name: str = name
         self.value: str = value
-        self.observations: Union[str, list[str]] = observations
+        self.observations: Union[str, List[str]] = observations
         self.element_parts = list()
