@@ -1,3 +1,5 @@
+from typing import List
+
 from xlsx_lib.domain.generic_replacements.replacement_part import ReplacementPart
 
 
@@ -6,7 +8,7 @@ class Replacement:
     name: str
     reference: str
     observations: str
-    parts: list[ReplacementPart]
+    parts: List[ReplacementPart]
 
     def __init__(self, name: str, reference: str, observations: str):
         self.name = name
