@@ -1,4 +1,4 @@
-from typing import Optional
+from typing import Optional, List
 
 from openpyxl import \
     Workbook, \
@@ -36,11 +36,11 @@ class MotorcycleModelWorkbook:
     def __init__(self, filename: any, directory: Optional[str] = None):
         workbook: Workbook = load_workbook(filename=filename)
 
-        generic_replacements: Optional[list[Replacement]] = None
-        electronic_elements: Optional[list[ElectronicElement]] = None
-        components_screws_tightening_torques: Optional[list[Component]] = None
-        engine_sections: Optional[list[EngineSection]] = None
-        frame_elements: Optional[list[FrameElement]] = None
+        generic_replacements: Optional[List[Replacement]] = None
+        electronic_elements: Optional[List[ElectronicElement]] = None
+        components_screws_tightening_torques: Optional[List[Component]] = None
+        engine_sections: Optional[List[EngineSection]] = None
+        frame_elements: Optional[List[FrameElement]] = None
 
         for sheetname in [key for key in workbook.sheetnames if key in sheetnames_relationships]:
             if sheetnames_relationships[sheetname] == Sheetnames.ENGINE:
