@@ -1,3 +1,5 @@
+from typing import List
+
 from xlsx_lib.domain.tightening_torques.tightening_torque_step import TighteningTorqueStep
 
 
@@ -10,5 +12,5 @@ class ComponentPartScrew:
     ):
         self.name: str = name
         self.tightening_torque: str = tightening_torque
-        self.steps: list[TighteningTorqueStep] = list[TighteningTorqueStep]()
+        self.steps: List[TighteningTorqueStep] = List[TighteningTorqueStep]()
         self.detail: str = detail
