@@ -1,5 +1,6 @@
 from openpyxl.cell import Cell
 from openpyxl.worksheet.worksheet import Worksheet
+from typing import List
 
 from xlsx_lib.domain.xlsx_elements.cell_position import CellPosition
 
@@ -20,8 +21,8 @@ class SheetReader:
             end_col: int,
             start_row: int,
             end_row: int,
-    ) -> list[str]:
-        values: list[str] = list()
+    ) -> List[str]:
+        values: List[str] = list()
         end_col += 1
         end_row += 1
 
@@ -51,8 +52,8 @@ class SheetReader:
             end_col: int,
             start_row: int,
             end_row: int,
-    ) -> list[Cell]:
-        cells: list[Cell] = list()
+    ) -> List[Cell]:
+        cells: List[Cell] = list()
         end_col += 1
         end_row += 1
 
